@@ -1,6 +1,6 @@
 /*
  * MONA
- * Copyright (C) 1997-2004 BRICS.
+ * Copyright (C) 1997-2007 BRICS.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -401,7 +401,7 @@ Code_c::equiv(Code &c)
 unsigned 
 Code_c::hash() 
 {
-  return kind + ((int) vc.code)*128;
+  return kind + ((long) vc.code)*128;
 }
 
 ////////// Code_cc ////////////////////////////////////////////////////////////
@@ -439,7 +439,7 @@ Code_cc::equiv(Code &c)
 unsigned 
 Code_cc::hash() 
 {
-  return kind*2 + ((int) vc1.code)*5 + ((int) vc2.code)*7;
+  return kind*2 + ((long) vc1.code)*5 + ((long) vc2.code)*7;
 }
 
 void 
@@ -1221,7 +1221,7 @@ Code_Import::equiv(Code &c)
 unsigned
 Code_Import::hash()
 {
-  return kind + (int) file;
+  return kind + (long) file;
 }
 
 void
@@ -1345,7 +1345,7 @@ Code_Export::equiv(Code &c)
 unsigned
 Code_Export::hash()
 {
-  return kind + (int) file;
+  return kind + (long) file;
 }
 
 void 
