@@ -1,6 +1,6 @@
 /*
  * MONA
- * Copyright (C) 1997-2004 BRICS.
+ * Copyright (C) 1997-2007 BRICS.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -199,7 +199,7 @@ void
 Usage()
 {
   cout << "MONA v" << VERSION << "-" << RELEASE << " for WS1S/WS2S\n"
-    << "Copyright (C) 1997-2004 BRICS\n\n"
+    << "Copyright (C) 1997-2007 BRICS\n\n"
     << "Usage: mona [options] <filename>\n\n"
     << "Options:\n"
     << " -w   Output whole automaton\n"
@@ -276,7 +276,7 @@ main(int argc, char *argv[])
 
   if (options.printProgress)
     cout << "MONA v" << VERSION << "-" << RELEASE <<  " for WS1S/WS2S\n"
-      "Copyright (C) 1997-2004 BRICS\n\n"
+      "Copyright (C) 1997-2007 BRICS\n\n"
       "PARSING\n";
 
   Timer timer_parsing;
@@ -507,16 +507,16 @@ main(int argc, char *argv[])
     printf("digraph MONA_CODE_DAG {\n"
 	   " size = \"7.5,10.5\";\n"
 	   " main [shape = plaintext];\n"
-	   " main -> L%x;\n", 
-	   (unsigned) formulaCode.code);
+	   " main -> L%lx;\n", 
+	   (unsigned long) formulaCode.code);
     formulaCode.code->viz();
     Deque<VarCode>::iterator i;
     Deque<char *>::iterator j;
     for (i = verifyCode.begin(), j = ast->verifytitlelist.begin(); 
 	 i != verifyCode.end(); i++, j++) {
       printf(" \"%s\" [shape = plaintext];\n"
-	     " \"%s\" -> L%x;\n", 
-	     *j, *j, (unsigned) (*i).code);
+	     " \"%s\" -> L%lx;\n", 
+	     *j, *j, (unsigned long) (*i).code);
       (*i).code->viz();
     }
     formulaCode.unmark();
